<?php
/**
 * Plugin Name: Interlinks Manager
 * Description: Manages the internal links of your WordPress website.
 * Version: 1.37
 * Author: DAEXT
 * Author URI: https://daext.com
 * Text Domain: interlinks-manager
 * License: GPLv3
 *
 * @package interlinks-manager
 */

// Prevent direct access to this file.
if ( ! defined( 'WPINC' ) ) {
	die(); }

// Set constants.
define('DAIM_EDITION', 'PRO');

// The URL of the REST API endpoint where the plugin update information are retrieved.
define( 'DAIM_WP_PLUGIN_UPDATE_INFO_API_URL', 'https://daext.com/wp-json/daext-commerce/v1/wp-plugin-update-info/' );

// Transient key for storing the plugin update information.
define( 'DAIM_WP_PLUGIN_UPDATE_INFO_TRANSIENT', 'daim_wp_plugin_update_info' );

// Class shared across public and admin.
require_once plugin_dir_path( __FILE__ ) . 'shared/class-daim-shared.php';

// Rest API.
require_once plugin_dir_path( __FILE__ ) . 'inc/class-daextdaim-rest.php';
add_action( 'plugins_loaded', array( 'Daextdaim_Rest', 'get_instance' ) );

// Update Checker.
require_once plugin_dir_path( __FILE__ ) . 'inc/class-daim-update-checker.php';
add_action( 'plugins_loaded', array( 'Daim_Update_Checker', 'get_instance' ) );

// Public.
require_once plugin_dir_path( __FILE__ ) . 'public/class-daim-public.php';
add_action( 'plugins_loaded', array( 'Daim_Public', 'get_instance' ) );

// Admin.
if ( is_admin() ) {

	require_once( plugin_dir_path( __FILE__ ) . 'admin/class-daim-admin.php' );

	// If this is not an AJAX request, create a new singleton instance of the admin class.
	if(! defined( 'DOING_AJAX' ) || ! DOING_AJAX ){
		add_action( 'plugins_loaded', array( 'Daim_Admin', 'get_instance' ) );
	}

	// Activate the plugin using only the class static methods.
	register_activation_hook( __FILE__, array( 'Daim_Admin', 'ac_activate' ) );

	// Deactivate the plugin only with static methods.
	register_deactivation_hook( __FILE__, array( 'Daim_Admin', 'dc_deactivate' ) );

	// Update the plugin db tables and options if they are not up-to-date.
	Daim_Admin::ac_create_database_tables();
	Daim_Admin::ac_initialize_options();

}

// Ajax.
if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {

	// Admin.
	require_once plugin_dir_path( __FILE__ ) . 'class-daim-ajax.php';
	add_action( 'plugins_loaded', array( 'Daim_Ajax', 'get_instance' ) );

}
